@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for B-Prolog 7.8 and later versions
-%  Last updated on August 7, 2016
+%  Last updated on December 11, 2017
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -509,7 +509,9 @@ findall(Term, Goal, List, Tail) :-
 
 '$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
 	% B-Prolog bug workarund: up to version 8.1, the lines are returned end line first!
-	read_term(Stream, Term, [line_counts(LineEnd, LineBegin), variable_names(Variables)| Options]).
+	read_term(Stream, Term, [line_counts(LineEnd, LineBegin), variable_names(Variables0)| Options]),
+	% workaround lack of compliance of the variable_names/1 option
+	reverse(Variables0, Variables).
 
 
 
@@ -722,11 +724,22 @@ term_hash(_, _, _, _) :-
 	logtalk_make(clean).
 {?} :-
 	!,
-	logtalk_make(missing).
+	logtalk_make(check).
 {@} :-
 	!,
 	logtalk_make(circular).
-
+{#} :-
+	!,
+	logtalk_make(documentation).
+{+d} :-
+	!,
+	logtalk_make(debug).
+{+n} :-
+	!,
+	logtalk_make(normal).
+{+o} :-
+	!,
+	logtalk_make(optimal).
 
 {File, Files} :-
 	!,
