@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for CxProlog 0.98.1 or a later version
-%  Last updated on August 7, 2016
+%  Last updated on January 26, 2018
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -63,7 +63,7 @@
 
 findall(Term, Goal, List, Tail) :-
 	findall(Term, Goal, List0),
-	'$lgt_append'(List0, Tail, List).
+	app(List0, Tail, List).
 
 
 % forall(+callable, +callable) -- built-in
@@ -108,7 +108,7 @@ findall(Term, Goal, List, Tail) :-
 
 setup_call_cleanup(Setup, Call, Cleanup) :-
 	once(Setup),
-	call_cleanup(Call, catch(Cleanup,_,true)).
+	call_cleanup(Call, (Cleanup->true;true)).
 
 
 
@@ -710,11 +710,22 @@ term_hash(_, _, _, _) :-
 	logtalk_make(clean).
 {?} :-
 	!,
-	logtalk_make(missing).
+	logtalk_make(check).
 {@} :-
 	!,
 	logtalk_make(circular).
-
+{#} :-
+	!,
+	logtalk_make(documentation).
+{+d} :-
+	!,
+	logtalk_make(debug).
+{+n} :-
+	!,
+	logtalk_make(normal).
+{+o} :-
+	!,
+	logtalk_make(optimal).
 
 {File, Files} :-
 	!,
