@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for ECLiPSe 6.1#143 and later versions
-%  Last updated on August 7, 2016
+%  Last updated on January 25, 2018
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -21,17 +21,39 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
+% this file should be loaded into module "user" with language set to "iso";
+% the provided "eclipselgt.sh" script ensures that by using the "eclipse"
+% command-line options "-L iso -t user"
+
 :- pragma(system).
 :- pragma(nodebug).
 
-:- use_module(library(iso)).
-:- ensure_loaded(library(iso_strict)).
-:- import compare/3, term_variables/2 from iso_strict.
+:- if((get_flag(version_as_list, Version), Version @< [7,0,24])).
+	:- ensure_loaded(library(iso_strict)).
+	:- import compare/3, term_variables/2 from iso_strict.
+:- endif.
+
+:- if((get_flag(version_as_list, Version), Version @>= [7,0,26])).
+	:- ensure_loaded(library(prolog_extras)).
+	:- import predicate_property/2 from prolog_extras.
+:- endif.
+
+:- if((get_flag(version_as_list, Version), Version @>= [7])).
+	:- use_module(library(threads)).
+	:- if(\+ get_flag(mutex_property/2, defined, on)).
+		mutex_property(_, alias(Alias)) :-
+			catch(with_mutex(Alias,true), _, fail).
+	:- endif.
+:- endif.
 
 :- set_event_handler(134, '$lgt_eclipse_discontiguous_predicate_handler'/2).
 
 '$lgt_eclipse_discontiguous_predicate_handler'(Err, Goal) :-
-	'$lgt_increment_loadind_warnings_counter',
+	(	'$lgt_increment_loading_warnings_counter' ->
+		true
+	;	% likely not compiling a Logtalk source file
+		true
+	),
 	error(default(Err), Goal).
 
 
@@ -66,8 +88,12 @@
 
 % between(+integer, +integer, ?integer)
 
-:- ensure_loaded(library(util)).
-:- import between/3 from util.
+:- if(\+ get_flag(between/3, type, built_in)).
+
+	:- ensure_loaded(library(util)).
+	:- import between/3 from util.
+
+:- endif.
 
 
 % findall(?term, +callable, ?list, +list)
@@ -130,7 +156,36 @@ forall(Generate, Test) :-
 '$lgt_eclipse_module_predicate_property'(Module, Predicate, meta_predicate(Template)) :-
 	get_flag(Predicate, meta_predicate, Template)@Module.
 
-'$lgt_eclipse_plain_predicate_property'(numbervars/3, built_in).
+:- if(\+ get_flag(numbervars/3, type, built_in)).
+	'$lgt_eclipse_plain_predicate_property'(numbervars/3, built_in).
+:- endif.
+:- if(get_flag(predicate_property/2, defined, on)).
+	'$lgt_eclipse_plain_predicate_property'(predicate_property/2, built_in).
+:- endif.
+:- if((get_flag(version_as_list, Version), Version @>= [7])).
+	'$lgt_eclipse_plain_predicate_property'(thread_exit/1, built_in).
+	'$lgt_eclipse_plain_predicate_property'(thread_sleep/1, built_in).
+	'$lgt_eclipse_plain_predicate_property'(thread_property/2, built_in).
+	'$lgt_eclipse_plain_predicate_property'(thread_self/1, built_in).
+	'$lgt_eclipse_plain_predicate_property'(thread_create/1, built_in).
+	'$lgt_eclipse_plain_predicate_property'(thread_create/2, built_in).
+	'$lgt_eclipse_plain_predicate_property'(thread_create/3, built_in).
+	'$lgt_eclipse_plain_predicate_property'(thread_join/2, built_in).
+	'$lgt_eclipse_plain_predicate_property'(thread_signal/2, built_in).
+	'$lgt_eclipse_plain_predicate_property'(thread_peek_message/1, built_in).
+	'$lgt_eclipse_plain_predicate_property'(thread_peek_message/2, built_in).
+	'$lgt_eclipse_plain_predicate_property'(thread_get_message/1, built_in).
+	'$lgt_eclipse_plain_predicate_property'(thread_get_message/2, built_in).
+	'$lgt_eclipse_plain_predicate_property'(thread_send_message/1, built_in).
+	'$lgt_eclipse_plain_predicate_property'(thread_send_message/2, built_in).
+	'$lgt_eclipse_plain_predicate_property'(mutex_create/1, built_in).
+	'$lgt_eclipse_plain_predicate_property'(mutex_create/2, built_in).
+	'$lgt_eclipse_plain_predicate_property'(with_mutex/2, built_in).
+	'$lgt_eclipse_plain_predicate_property'(message_queue_create/2, built_in).
+	'$lgt_eclipse_plain_predicate_property'(message_queue_create/1, built_in).
+	'$lgt_eclipse_plain_predicate_property'(message_queue_destroy/1, built_in).
+:- endif.
+
 '$lgt_eclipse_plain_predicate_property'(Predicate, built_in) :-
 	get_flag(Predicate, type, built_in).
 '$lgt_eclipse_plain_predicate_property'(Predicate, dynamic) :-
@@ -149,7 +204,12 @@ forall(Generate, Test) :-
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
-% setup_call_cleanup(+callable, +callable, +callable) -- not supported
+% setup_call_cleanup(+callable, +callable, +callable)
+
+:- if((get_flag(version_as_list, Version), Version @> [7,0,24])).
+    :- ensure_loaded(library(prolog_extras)).
+    :- import setup_call_cleanup/3 from prolog_extras.
+:- endif.
 
 
 
@@ -180,7 +240,14 @@ forall(Generate, Test) :-
 '$lgt_prolog_meta_predicate'(subcall(_, _), subcall(0, *), predicate).
 '$lgt_prolog_meta_predicate'(suspend(_, _, _), suspend(0, *, *), predicate).
 '$lgt_prolog_meta_predicate'(suspend(_, _, _, _), suspend(0, *, *, *), predicate).
-
+:- if((get_flag(version_as_list, Version), Version @>= [7,0,35])).
+	'$lgt_prolog_meta_predicate'(engine_post(_, _), engine_post(*, 0), predicate).
+	'$lgt_prolog_meta_predicate'(thread_create(_), thread_create(0), predicate).
+	'$lgt_prolog_meta_predicate'(thread_create(_, _), thread_create(0, *), predicate).
+	'$lgt_prolog_meta_predicate'(thread_create(_, _, _), thread_create(0, *, *), predicate).
+	'$lgt_prolog_meta_predicate'(thread_signal(_, _), thread_signal(*, 0), predicate).
+	'$lgt_prolog_meta_predicate'(with_mutex(_, _), with_mutex(*, 0), predicate).
+:- endif.
 
 % '$lgt_prolog_meta_directive'(@callable, -callable)
 
@@ -253,7 +320,11 @@ forall(Generate, Test) :-
 
 '$lgt_prolog_feature'(encoding_directive, unsupported).
 '$lgt_prolog_feature'(tabling, unsupported).
-'$lgt_prolog_feature'(threads, unsupported).
+%:- if(get_flag(thread_create/3, defined, on)).
+%	'$lgt_prolog_feature'(threads, supported).
+%:- else.
+	'$lgt_prolog_feature'(threads, unsupported).
+%:- endif.
 '$lgt_prolog_feature'(modules, supported).
 '$lgt_prolog_feature'(coinduction, supported).
 '$lgt_prolog_feature'(unicode, unsupported).
@@ -329,7 +400,13 @@ forall(Generate, Test) :-
 % expands a file path to a full path
 
 '$lgt_expand_path'(Path, ExpandedPath) :-
-	canonical_path_name(Path, ExpandedPath).
+	canonical_path_name(Path, ExpandedPath0),
+	% delete any ending slash as we can have a file with
+	% the same name (minus extension) as a sub-directory
+	(	sub_atom(ExpandedPath0, _, 1, 0, '/') ->
+		sub_atom(ExpandedPath0, 0, _, 1, ExpandedPath)
+	;	ExpandedPath = ExpandedPath0
+	).
 
 
 % '$lgt_file_exists'(+atom)
@@ -534,13 +611,19 @@ forall(Generate, Test) :-
 
 % '$lgt_read_term'(@stream, -term, +list, -position, -list)
 
-'$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
-	get_stream_info(Stream, line, LineBegin),
-	(	read_term(Stream, Term, [variable_names(Variables)| Options]) ->
-		get_stream_info(Stream, line, LineEnd)
-	;	throw(syntax_error)
-	).
-
+:- if((get_flag(version_as_list, Version), Version @>= [7,0,35])).
+	'$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
+		get_stream_info(Stream, line, LineBegin),
+		read_term(Stream, Term, [syntax_errors(error), variable_names(Variables)| Options]),
+		get_stream_info(Stream, line, LineEnd).
+:- else.
+	'$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
+		get_stream_info(Stream, line, LineBegin),
+		(	read_term(Stream, Term, [variable_names(Variables)| Options]) ->
+			get_stream_info(Stream, line, LineEnd)
+		;	throw(syntax_error)
+		).
+:- endif.
 
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -581,7 +664,7 @@ forall(Generate, Test) :-
 	'$lgt_compile_predicate_indicators'(Functor/Arity, _, CFunctor/CArity).
 
 '$lgt_eclipse_directive_expansion'(import(from(Conjunction, Module)), use_module(Module, Imports)) :-
-	'$lgt_flatten_list'([Conjunction], Imports).
+	'$lgt_flatten_to_list'(Conjunction, Imports).
 
 '$lgt_eclipse_directive_expansion'(local(Functor/Arity), private(Functor/Arity)).
 '$lgt_eclipse_directive_expansion'(local(op(Priority, Spec, Operators)), op(Priority, Spec, Operators)).
@@ -595,7 +678,7 @@ forall(Generate, Test) :-
 	'$lgt_eclipse_list_of_exports'(File, Module, Exports).
 
 '$lgt_eclipse_directive_expansion'(reexport(from(Conjunction, Module)), reexport(Module, Exports)) :-
-	'$lgt_flatten_list'([Conjunction], Exports).
+	'$lgt_flatten_to_list'(Conjunction, Exports).
 
 '$lgt_eclipse_directive_expansion'(use_module(File), use_module(Module, Imports)) :-
 	logtalk_load_context(entity_type, _),
@@ -814,11 +897,22 @@ forall(Generate, Test) :-
 	logtalk_make(clean).
 {?} :-
 	!,
-	logtalk_make(missing).
+	logtalk_make(check).
 {@} :-
 	!,
 	logtalk_make(circular).
-
+{#} :-
+	!,
+	logtalk_make(documentation).
+{+d} :-
+	!,
+	logtalk_make(debug).
+{+n} :-
+	!,
+	logtalk_make(normal).
+{+o} :-
+	!,
+	logtalk_make(optimal).
 
 {File, Files} :-
 	!,
