@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Adapter file for GNU Prolog 1.4.2 (and later versions)
-%  Last updated on August 7, 2016
+%  Adapter file for GNU Prolog 1.4.5 (and later versions)
+%  Last updated on February 16, 2018
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -21,7 +21,6 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
-
 :- built_in.
 :- set_prolog_flag(strict_iso, off).
 
@@ -111,6 +110,7 @@ setup_call_cleanup(_, _, _) :-
 	throw(not_supported(setup_call_cleanup/3)).
 
 
+
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Prolog non-standard built-in meta-predicates and meta-directives
@@ -194,7 +194,7 @@ setup_call_cleanup(_, _, _) :-
 '$lgt_prolog_feature'(prolog_dialect, gnu).
 '$lgt_prolog_feature'(prolog_version, (Major, Minor, Patch)) :-
 	catch(current_prolog_flag(version_data, gprolog(Major, Minor, Patch, _)), _, fail).
-'$lgt_prolog_feature'(prolog_compatible_version, @>=((1,4,2))).
+'$lgt_prolog_feature'(prolog_compatible_version, @>=((1,4,5))).
 '$lgt_prolog_feature'(prolog_conformance, Mode) :-
 	(	current_prolog_flag(strict_iso, on) ->
 		Mode = strict
@@ -344,8 +344,7 @@ setup_call_cleanup(_, _, _) :-
 
 '$lgt_directory_hash_as_atom'(Directory, Hash) :-
 	term_hash(Directory, Hash0),
-	number_codes(Hash0, Codes),
-	atom_codes(Hash, Codes).
+	number_atom(Hash0, Hash).
 
 
 % '$lgt_compile_prolog_code'(+atom, +atom, +list)
@@ -474,9 +473,13 @@ setup_call_cleanup(_, _, _) :-
 % '$lgt_read_term'(@stream, -term, +list, -position, -list)
 
 '$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
-	line_count(Stream, LineBegin),
 	read_term(Stream, Term, [syntax_error(error), variable_names(Variables)| Options]),
-	line_count(Stream, LineEnd).
+	last_read_start_line_column(LineBegin, _),
+	stream_line_column(Stream, Line, Col),
+	(	Col = 1 ->
+		LineEnd is Line - 1
+	;	LineEnd = Line
+	).
 
 
 
@@ -606,7 +609,6 @@ thread_join(_, _) :- fail.
 with_mutex(_, _) :- fail.
 message_queue_create(_) :- fail.
 message_queue_destroy(_) :- fail.
-:- dynamic('$lgt_engine_term_queue_'/2).
 
 
 
@@ -730,11 +732,22 @@ message_queue_destroy(_) :- fail.
 	logtalk_make(clean).
 {?} :-
 	!,
-	logtalk_make(missing).
+	logtalk_make(check).
 {@} :-
 	!,
 	logtalk_make(circular).
-
+{#} :-
+	!,
+	logtalk_make(documentation).
+{+d} :-
+	!,
+	logtalk_make(debug).
+{+n} :-
+	!,
+	logtalk_make(normal).
+{+o} :-
+	!,
+	logtalk_make(optimal).
 
 {File, Files} :-
 	!,
