@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Adapter file for JIProlog 4.1.2.8 or later versions
-%  Last updated on August 7, 2016
+%  Adapter file for JIProlog 4.1.6.1 or later versions
+%  Last updated on March 15, 2018
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -78,57 +78,10 @@
 % forall(+callable, +callable) -- built-in
 
 
-% format(+stream_or_alias, +character_code_list_or_atom, +list)
-
-format(Stream, Format, Arguments) :-
-	atom_codes(Format, Codes),
-	format_(Codes, Stream, Arguments).
-
-format_([], _, _).
-format_([0'~, Spec| Codes], Stream, Arguments) :-
-	!,
-	format_spec_(Spec, Stream, Arguments, RemainingArguments),
-	format_(Codes, Stream, RemainingArguments).
-format_([Code| Codes], Stream, Arguments) :-
-	put_code(Stream, Code),
-	format_(Codes, Stream, Arguments).
-
-format_spec_(0'a, Stream, [Argument| Arguments], Arguments) :-
-%	atom(Argument),
-	write(Stream, Argument).
-format_spec_(0'c, Stream, [Argument| Arguments], Arguments) :-
-	put_code(Stream, Argument).
-format_spec_(0's, Stream, [Argument| Arguments], Arguments) :-
-	atom_codes(Atom, Argument),
-	write(Stream, Atom).
-format_spec_(0'w, Stream, [Argument| Arguments], Arguments) :-
-	write(Stream, Argument).
-format_spec_(0'q, Stream, [Argument| Arguments], Arguments) :-
-	writeq(Stream, Argument).
-format_spec_(0'k, Stream, [Argument| Arguments], Arguments) :-
-	write_canonical(Stream, Argument).
-format_spec_(0'd, Stream, [Argument| Arguments], Arguments) :-
-	write(Stream, Argument).
-format_spec_(0'D, Stream, [Argument| Arguments], Arguments) :-
-	write(Stream, Argument).
-format_spec_(0'f, Stream, [Argument| Arguments], Arguments) :-
-	write(Stream, Argument).
-format_spec_(0'g, Stream, [Argument| Arguments], Arguments) :-
-	write(Stream, Argument).
-format_spec_(0'G, Stream, [Argument| Arguments], Arguments) :-
-	write(Stream, Argument).
-format_spec_(0'i, _, [_| Arguments], Arguments).
-format_spec_(0'n, Stream, Arguments, Arguments) :-
-	nl(Stream).
-format_spec_(0'~, Stream, Arguments, Arguments) :-
-	put_code(Stream, 0'~).
+% format(+stream_or_alias, +character_code_list_or_atom, +list) -- built-in
 
 
-% format(+character_code_list_or_atom, +list)
-
-format(Format, Arguments) :-
-	current_output(Stream),
-	format(Stream, Format, Arguments).
+% format(+character_code_list_or_atom, +list) -- built-in
 
 
 % numbervars(?term, +integer, ?integer) -- built-in
@@ -222,7 +175,7 @@ format(Format, Arguments) :-
 '$lgt_prolog_feature'(prolog_dialect, ji).
 '$lgt_prolog_feature'(prolog_version, (Major, Minor, Patch)) :-
 	current_prolog_flag(version_data, jiprolog(Major, Minor, Patch, _)).
-'$lgt_prolog_feature'(prolog_compatible_version, @>=((4,1,2))).
+'$lgt_prolog_feature'(prolog_compatible_version, @>=((4,1,6))).
 '$lgt_prolog_feature'(prolog_conformance, lax).
 
 '$lgt_prolog_feature'(encoding_directive, source).
@@ -265,7 +218,13 @@ format(Format, Arguments) :-
 '$lgt_default_flag'(events, deny).
 '$lgt_default_flag'(context_switching_calls, allow).
 % other compilation flags:
-'$lgt_default_flag'(scratch_directory, './').
+'$lgt_default_flag'(scratch_directory, ScratchDirectory) :-
+	(	invoke('java.lang.System', getProperty('java.lang.String'), ['os.name'], Name),
+		sub_atom(Name, 0, 7, _, 'Windows') ->
+		ScratchDirectory = './lgt_tmp/'
+	;	% assume POSIX system
+		ScratchDirectory = './.lgt_tmp/'
+	).
 '$lgt_default_flag'(report, on).
 '$lgt_default_flag'(clean, on).
 '$lgt_default_flag'(code_prefix, '$').
@@ -299,33 +258,8 @@ format(Format, Arguments) :-
 % expands a file path to a full path
 
 '$lgt_expand_path'(Path, ExpandedPath) :-
-	% first expand any environment variable
-	'$lgt_ji_expand_environment'(Path, ExpandedPath0),
-	(	(	sub_atom(ExpandedPath0, 0, 1, _, '/')
-			% assume POSIX full path 
-		;	sub_atom(ExpandedPath0, 1, 1, _, ':')
-			% assume Windows full Path starting with a drive letter followed by ":"
-		) ->
-		% assume full path
-		ExpandedPath = ExpandedPath0
-	;	% assume path relative to the current directory
-		'$lgt_current_directory'(Directory),
-		atom_concat(Directory, ExpandedPath0, ExpandedPath)
-	).
-
-
-'$lgt_ji_expand_environment'(Path, ExpandedPath) :-
-	'$lgt_ji_convert_file_path'(Path, Path1),
-	(	sub_atom(Path1, 0, 1, _, '$'),
-		sub_atom(Path1, Before, _, _, '/') ->
-		End is Before - 1,
-		sub_atom(Path1, 1, End, _, Variable),
-		sub_atom(Path1, Before, _, 0, Rest),
-		'$lgt_environment_variable'(Variable, Value0),
-		'$lgt_ji_convert_file_path'(Value0, Value),
-		atom_concat(Value, Rest, ExpandedPath)
-	;	Path1 = ExpandedPath
-	).
+	absolute_file_name(Path, ExpandedPath0),
+	'$lgt_ji_convert_file_path'(ExpandedPath0, ExpandedPath).
 
 
 % '$lgt_file_exists'(+atom)
@@ -386,8 +320,7 @@ format(Format, Arguments) :-
 % changes current working directory
 
 '$lgt_change_directory'(Directory) :-
-	'$lgt_expand_path'(Directory, Expanded),
-	chdir(Expanded).
+	chdir(Directory).
 
 
 % '$lgt_make_directory'(+atom)
@@ -395,10 +328,9 @@ format(Format, Arguments) :-
 % makes a new directory; succeeds if the directory already exists
 
 '$lgt_make_directory'(Directory) :-
-	'$lgt_expand_path'(Directory, Expanded),
-	(	exists_directory(Expanded) ->
+	(	exists_directory(Directory) ->
 		true
-	;	make_directory(Expanded)
+	;	make_directory(Directory)
 	).
 
 
@@ -727,11 +659,22 @@ term_hash(_, _, _, _) :-
 	logtalk_make(clean).
 {?} :-
 	!,
-	logtalk_make(missing).
+	logtalk_make(check).
 {@} :-
 	!,
 	logtalk_make(circular).
-
+{#} :-
+	!,
+	logtalk_make(documentation).
+{+d} :-
+	!,
+	logtalk_make(debug).
+{+n} :-
+	!,
+	logtalk_make(normal).
+{+o} :-
+	!,
+	logtalk_make(optimal).
 
 {File, Files} :-
 	!,
