@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for Lean Prolog 4.5.7 and later versions
-%  Last updated on August 7, 2016
+%  Last updated on February 11, 2018
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -688,8 +688,6 @@ message_queue_create(_) :-
 message_queue_destroy(_) :-
 	fail.
 
-:- dynamic('$lgt_engine_term_queue_'/2).
-
 
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -926,11 +924,22 @@ term_hash(_, _, _, _) :-
 	logtalk_make(clean).
 {(?)} :-
 	!,
-	logtalk_make(missing).
+	logtalk_make(check).
 {@} :-
 	!,
 	logtalk_make(circular).
-
+{'#'} :-
+	!,
+	logtalk_make(documentation).
+{+d} :-
+	!,
+	logtalk_make(debug).
+{+n} :-
+	!,
+	logtalk_make(normal).
+{+o} :-
+	!,
+	logtalk_make(optimal).
 
 {File, Files} :-
 	!,
