@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for Qu-Prolog 9.7 and later versions
-%  Last updated on August 7, 2016
+%  Last updated on December 11, 2017
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -315,7 +315,7 @@ format(Format, Arguments) :-
 '$lgt_default_flag'(reload, changed).
 '$lgt_default_flag'(debug, off).
 % Prolog compiler and loader flags:
-'$lgt_default_flag'(prolog_compiler, [assemble_only(true), string_table(2048), compiler_heap(4096), compiler_scratchpad(512)]).
+'$lgt_default_flag'(prolog_compiler, [assemble_only(true), string_table(4096), compiler_heap(8192), compiler_scratchpad(1024)]).
 '$lgt_default_flag'(prolog_loader, []).
 
 
@@ -556,8 +556,15 @@ format(Format, Arguments) :-
 
 '$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
 	stream_property(Stream, line_number(LineBegin)),
-	read_term(Stream, Term, [variable_names(Variables)| Options]),
-	stream_property(Stream, line_number(LineEnd)).
+	read_term(Stream, Term, [variable_names(Variables0)| Options]),
+	stream_property(Stream, line_number(LineEnd)),
+	% workaround lack of compliance of the variable_names/1 option
+	'$lgt_qp_fix_variable_names'(Variables0, Variables).
+
+
+'$lgt_qp_fix_variable_names'([], []).
+'$lgt_qp_fix_variable_names'([Variable=Name| Variables0], [Name=Variable| Variables]) :-
+	'$lgt_qp_fix_variable_names'(Variables0, Variables).
 
 
 
@@ -758,11 +765,22 @@ term_hash(_, _, _, _) :-
 	logtalk_make(clean).
 {?} :-
 	!,
-	logtalk_make(missing).
+	logtalk_make(check).
 {@} :-
 	!,
 	logtalk_make(circular).
-
+{#} :-
+	!,
+	logtalk_make(documentation).
+{+d} :-
+	!,
+	logtalk_make(debug).
+{+n} :-
+	!,
+	logtalk_make(normal).
+{+o} :-
+	!,
+	logtalk_make(optimal).
 
 {File, Files} :-
 	!,
