@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for Quintus Prolog 3.3~3.5
-%  Last updated on August 7, 2016
+%  Last updated on March 15, 2018
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -66,12 +66,24 @@
 '$lgt_iso_predicate'(current_predicate(_)).
 '$lgt_iso_predicate'(current_prolog_flag(_, _)).
 '$lgt_iso_predicate'(flush_output).
+'$lgt_iso_predicate'(get_byte(_)).
+'$lgt_iso_predicate'(get_byte(_, _)).
+'$lgt_iso_predicate'(get_char(_)).
+'$lgt_iso_predicate'(get_char(_, _)).
 '$lgt_iso_predicate'(get_code(_)).
 '$lgt_iso_predicate'(get_code(_, _)).
 '$lgt_iso_predicate'(number_codes(_, _)).
 '$lgt_iso_predicate'(once(_)).
+'$lgt_iso_predicate'(peek_byte(_)).
+'$lgt_iso_predicate'(peek_byte(_, _)).
+'$lgt_iso_predicate'(peek_char(_)).
+'$lgt_iso_predicate'(peek_char(_, _)).
 '$lgt_iso_predicate'(peek_code(_)).
 '$lgt_iso_predicate'(peek_code(_, _)).
+'$lgt_iso_predicate'(put_byte(_)).
+'$lgt_iso_predicate'(put_byte(_, _)).
+'$lgt_iso_predicate'(put_char(_)).
+'$lgt_iso_predicate'(put_char(_, _)).
 '$lgt_iso_predicate'(put_code(_)).
 '$lgt_iso_predicate'(put_code(_, _)).
 '$lgt_iso_predicate'(set_prolog_flag(_, _)).
@@ -149,6 +161,24 @@ flush_output :-
 	flush_output(Stream).
 
 
+get_byte(Stream, Byte) :-
+	get0(Stream, Byte).
+
+
+get_byte(Byte) :-
+	get0(Byte).
+
+
+get_char(Stream, Char) :-
+	get0(Stream, Code),
+	atom_chars(Char, [Code]).
+
+
+get_char(Char) :-
+	get0(Code),
+	atom_chars(Char, [Code]).
+
+
 get_code(Stream, Code) :-
 	get0(Stream, Code).
 
@@ -166,6 +196,24 @@ once(Goal) :-
 	!.
 
 
+peek_byte(Stream, Byte) :-
+	peek_char(Stream, Byte).
+
+
+peek_byte(Byte) :-
+	peek_char(Byte).
+
+
+peek_char(Stream, Char) :-
+	peek_char(Stream, Code),
+	atom_chars(Char, [Code]).
+
+
+peek_char(Char) :-
+	peek_char(Code),
+	atom_chars(Char, [Code]).
+
+
 peek_code(Stream, Code) :-
 	peek_char(Stream, Code).
 
@@ -174,6 +222,24 @@ peek_code(Code) :-
 	peek_char(Code).
 
 
+put_byte(Stream, Byte) :-
+	put(Stream, Byte).
+
+
+put_byte(Byte) :-
+	put(Byte).
+
+
+put_char(Stream, Char) :-
+	atom_chars(Char, [Code]),	
+	put(Stream, Code).
+
+
+put_char(Char) :-
+	atom_chars(Char, [Code]),	
+	put(Code).
+
+
 put_code(Stream, Code) :-
 	put(Stream, Code).
 
@@ -729,7 +795,7 @@ call(F, A1, A2, A3, A4, A5, A6) :-
 
 '$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
 	line_count(Stream, LineBegin),
-	read_term(Stream, [variable_names(Variables)| Options], Term),
+	read_term(Stream, [syntax_errors(error), variable_names(Variables)| Options], Term),
 	line_count(Stream, LineEnd).
 
 
@@ -813,7 +879,7 @@ call(F, A1, A2, A3, A4, A5, A6) :-
 '$lgt_quintus_arithmetic_function_1'(ceiling(X), Result, X, ResultX, ceiling(ResultX, Result)).
 '$lgt_quintus_arithmetic_function_1'(cos(X), Result, X, ResultX, cos(ResultX, Result)).
 '$lgt_quintus_arithmetic_function_1'(exp(X), Result, X, ResultX, exp(ResultX, Result)).
-'$lgt_quintus_arithmetic_function_1'(float(X), Result, X, ResultX, float(ResultX, Result)).
+'$lgt_quintus_arithmetic_function_1'(float(X), Result, X, ResultX, Result is float(ResultX)).
 '$lgt_quintus_arithmetic_function_1'(floor(X), Result, X, ResultX, floor(ResultX, Result)).
 '$lgt_quintus_arithmetic_function_1'(log(X), Result, X, ResultX, log(ResultX, Result)).
 '$lgt_quintus_arithmetic_function_1'(round(X), Result, X, ResultX, round(ResultX, Result)).
@@ -987,11 +1053,22 @@ term_hash(_, _, _, _) :-
 	logtalk_make(clean).
 {?} :-
 	!,
-	logtalk_make(missing).
+	logtalk_make(check).
 {@} :-
 	!,
 	logtalk_make(circular).
-
+{#} :-
+	!,
+	logtalk_make(documentation).
+{+d} :-
+	!,
+	logtalk_make(debug).
+{+n} :-
+	!,
+	logtalk_make(normal).
+{+o} :-
+	!,
+	logtalk_make(optimal).
 
 {File, Files} :-
 	!,
