@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for SICStus Prolog 4.1.0 and later versions
-%  Last updated on August 7, 2016
+%  Last updated on February 8, 2018
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -139,7 +139,7 @@ forall(Generate, Test) :-
 
 	setup_call_cleanup(Setup, Call, Cleanup) :-
 		once(Setup),
-		call_cleanup(Call, catch(Cleanup,_,true)).
+		call_cleanup(Call, (Cleanup->true;true)).
 
 :- endif.
 
@@ -299,7 +299,11 @@ forall(Generate, Test) :-
 	;	% ... but not POSIX systems
 		ScratchDirectory = './.lgt_tmp/'
 	).
-'$lgt_default_flag'(report, on).
+'$lgt_default_flag'(report, Report) :-
+	(	current_prolog_flag(informational, off) ->
+		Report = warnings
+	;	Report = on
+	).
 '$lgt_default_flag'(clean, on).
 '$lgt_default_flag'(code_prefix, '$').
 '$lgt_default_flag'(optimize, off).
@@ -556,10 +560,11 @@ forall(Generate, Test) :-
 % '$lgt_read_term'(@stream, -term, +list, -position, -list)
 
 '$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
-	stream_position(Stream, PositionBegin),
-	stream_position_data(line_count, PositionBegin, LineCountBegin),
-	LineBegin is LineCountBegin + 1,
-	read_term(Stream, Term, [variable_names(Variables)| Options]),
+	read_term(Stream, Term, [layout(Layout), syntax_errors(error), variable_names(Variables)| Options]),
+	(	Layout = [LineBegin| _] ->
+		true
+	;	LineBegin = Layout
+	),
 	stream_position(Stream, PositionEnd),
 	stream_position_data(line_count, PositionEnd, LineCountEnd),
 	LineEnd is LineCountEnd + 1.
@@ -823,11 +828,22 @@ forall(Generate, Test) :-
 	logtalk_make(clean).
 {?} :-
 	!,
-	logtalk_make(missing).
+	logtalk_make(check).
 {@} :-
 	!,
 	logtalk_make(circular).
-
+{#} :-
+	!,
+	logtalk_make(documentation).
+{+d} :-
+	!,
+	logtalk_make(debug).
+{+n} :-
+	!,
+	logtalk_make(normal).
+{+o} :-
+	!,
+	logtalk_make(optimal).
 
 {File, Files} :-
 	!,
