@@ -5,10 +5,10 @@
 %  make/0, and to improve usability when using the XPCE profiler and XPCE
 %  graphical debugger
 %
-%  Last updated on June 27, 2016
+%  Last updated on November 28, 2017
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -48,7 +48,7 @@ user:prolog_load_file(_:Spec, Flags) :-
 	;	Spec =.. [Library, File],
 		% no paths instead of a file name for Logtalk
 		atom(File),
-		'$lgt_expand_library_path'(Library, LibPath),
+		'$lgt_expand_library_alias'(Library, LibPath),
 		atom_concat(LibPath, File, Spec2),
 		expand_file_name(Spec2, [SpecExp]),
 		absolute_file_name(SpecExp, [extensions(LogtalkExtensions), access(read), file_errors(fail)], Path)
@@ -75,7 +75,7 @@ prolog_edit:locate(Spec, source_file(Source), [file(Source)]) :-
 	compound(Spec),
 	Spec =.. [Library, Name],
 	atom(Name),
-	'$lgt_expand_library_path'(Library, LibraryPath),
+	'$lgt_expand_library_alias'(Library, LibraryPath),
 	atom_concat(LibraryPath, Name, LogtalkPath),
 	(	file_name_extension(_, Extension, LogtalkPath),
 		atom_concat('.', Extension, DotExtension),
@@ -88,6 +88,31 @@ prolog_edit:locate(Spec, source_file(Source), [file(Source)]) :-
 	!.
 
 
+/*	
+% experimental hack to get a stack trace for errors
+% generated from top-level message sending calls
+
+:- use_module(library(prolog_stack)).
+
+user:prolog_exception_hook(Exception, Exception, Frame, CatchFrame) :-
+	\+ atom(CatchFrame),
+	prolog_frame_attribute(CatchFrame, predicate_indicator, PI),
+	memberchk(PI, [(::)/2, (<<)/2]),
+    get_prolog_backtrace(Frame, 20, Trace),
+	'$lgt_swi_filter_trace'(Trace, Tracefiltered),
+    format(user_error, 'Error: ~p', [Exception]), nl(user_error),
+    print_prolog_backtrace(user_error, Tracefiltered), nl(user_error),
+	fail.
+
+'$lgt_swi_filter_trace'([], []).
+'$lgt_swi_filter_trace'([frame(N,C,G0)| Trace], [frame(N,C,Entity::Head)| Tracefiltered]) :-
+	'$lgt_decompile_predicate_heads'(G0, Entity, _, Head),
+	!,
+	'$lgt_swi_filter_trace'(Trace, Tracefiltered).
+'$lgt_swi_filter_trace'([_| Trace], Tracefiltered) :-
+	'$lgt_swi_filter_trace'(Trace, Tracefiltered).
+*/
+
 % for e.g. the call stack in the SWI-Prolog graphical tracer
 :- multifile(user:prolog_predicate_name/2).
 
@@ -687,15 +712,11 @@ user:portray(c(This, Entity, Rest)) :-
 :- meta_predicate '$lgt_category_property_resource'(*,*,*,*,*).
 :- meta_predicate '$lgt_category_property_resources'(*,*,*,*,*).
 
+:- meta_predicate '$lgt_check_for_tautology_or_falsehood_goal'(*,*).
+
 :- meta_predicate '$lgt_assert_pred_def'(*,*,*,*,*,*,*,*).
 :- meta_predicate '$lgt_send_to_self_nv'(*,*,*).
 
-:- meta_predicate threaded_ignore(*).
-:- meta_predicate threaded_once(*,*).
-:- meta_predicate threaded_call(*,*).
-:- meta_predicate threaded_call(*).
-:- meta_predicate threaded_once(*).
-
 :- meta_predicate '$lgt_threaded_goal'(*,*,*,*).
 :- meta_predicate '$lgt_threaded_call'(*,*,*,*).
 :- meta_predicate '$lgt_threaded_once'(*,*,*,*).
@@ -714,7 +735,6 @@ user:portray(c(This, Entity, Rest)) :-
 :- meta_predicate '$lgt_obj_super_call'(*,*,*).
 :- meta_predicate '$lgt_send_to_obj'(*,*,*).
 :- meta_predicate '$lgt_send_to_self'(*,*,*).
-:- meta_predicate '$lgt_call_proxy'(*,*,*).
 :- meta_predicate '$lgt_call_within_context_nv'(*,*,*).
 :- meta_predicate '$lgt_call_within_context'(*,*,*).
 
@@ -724,7 +744,6 @@ user:portray(c(This, Entity, Rest)) :-
 :- meta_predicate '$lgt_metacall_sender'(*,*,*,*).
 :- meta_predicate '$lgt_metacall_local'(*,*).
 
-:- meta_predicate threaded_engine_create(*,*,*).
 :- meta_predicate '$lgt_mt_engine_goal'(*,*,*,*,*).
 :- meta_predicate '$lgt_threaded_engine_create_protected'(*,*,*,*,*).
 :- meta_predicate '$lgt_threaded_engine_create'(*,*,*,*,*).
