@@ -3,8 +3,8 @@
 %  Adapter file for <your Prolog compiler name here>
 %  Last updated on <date of latest update>
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -622,10 +622,13 @@ term_hash(Term, Depth, Range, Hash) :-
 	logtalk_make(clean).
 {?} :-
 	!,
-	logtalk_make(missing).
+	logtalk_make(check).
 {@} :-
 	!,
 	logtalk_make(circular).
+{#} :-
+	!,
+	logtalk_make(documentation).
 
 
 {File, Files} :-
