@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Adapter file for XSB 3.5.0 or later versions
-%  Last updated on August 7, 2016
+%  Adapter file for XSB 3.8.0 or later versions
+%  Last updated on February 16, 2018
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -21,7 +21,6 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
-:- import datime/1 from standard.
 :- import expand_atom/2 from standard.
 :- import term_hash/3 from machine.
 
@@ -64,10 +63,14 @@
 % forall(+callable, +callable) -- built-in
 
 
-% format(+stream_or_alias, +character_code_list_or_atom, +list) -- built-in
+% format(+stream_or_alias, +character_code_list_or_atom, +list)
+
+:- import format/3 from format.
 
 
-% format(+character_code_list_or_atom, +list) -- built-in
+% format(+character_code_list_or_atom, +list)
+
+:- import format/2 from format.
 
 
 % numbervars(?term, +integer, ?integer) -- built-in
@@ -103,14 +106,7 @@
 
 setup_call_cleanup(Setup, Call, Cleanup) :-
 	once(Setup),
-	call_cleanup(Call, catch(Cleanup,_,true)).
-
-
-% setup_call_catcher_cleanup(+callable, +callable, ?term, +callable)
-
-setup_call_catcher_cleanup(Setup, Call, Catcher, Cleanup) :-
-	once(Setup),
-	catch(Call, Catcher, catch(Cleanup,_,true)).
+	call_cleanup(Call, (Cleanup->true;true)).
 
 
 
@@ -215,7 +211,7 @@ setup_call_catcher_cleanup(Setup, Call, Catcher, Cleanup) :-
 '$lgt_prolog_feature'(prolog_dialect, xsb).
 '$lgt_prolog_feature'(prolog_version, (Major, Minor, Patch)) :-
 	current_prolog_flag(version_data, xsb(Major, Minor, Patch, _)).
-'$lgt_prolog_feature'(prolog_compatible_version, @>=((3,5,0))).
+'$lgt_prolog_feature'(prolog_compatible_version, @>=((3,8,0))).
 '$lgt_prolog_feature'(prolog_conformance, lax).
 
 '$lgt_prolog_feature'(encoding_directive, unsupported).
@@ -259,11 +255,7 @@ setup_call_catcher_cleanup(Setup, Call, Catcher, Cleanup) :-
 '$lgt_default_flag'(events, deny).
 '$lgt_default_flag'(context_switching_calls, allow).
 % other compilation flags:
-'$lgt_default_flag'(scratch_directory, ScratchDirectory) :-
-	(	xsb_configuration(os_type, windows) ->
-		ScratchDirectory = './lgt_tmp/'
-	;	ScratchDirectory = './.lgt_tmp/'
-	).
+'$lgt_default_flag'(scratch_directory, './').
 '$lgt_default_flag'(report, on).
 '$lgt_default_flag'(clean, on).
 '$lgt_default_flag'(code_prefix, '$').
@@ -298,7 +290,8 @@ setup_call_catcher_cleanup(Setup, Call, Catcher, Cleanup) :-
 
 '$lgt_expand_path'(Path, ExpandedPath) :-
 	expand_atom(Path, EnvVarExpandedPath),
-	path_sysop(expand, EnvVarExpandedPath, ExpandedPath).
+	path_sysop(expand, EnvVarExpandedPath, ExpandedPath0),
+	ExpandedPath = ExpandedPath0.
 
 
 % '$lgt_file_exists'(+atom)
@@ -685,6 +678,13 @@ setup_call_catcher_cleanup(Setup, Call, Catcher, Cleanup) :-
 	existence_error(procedure, ':'(usermod, Functor/Arity)),
 	existence_error(procedure, Functor/Arity)
 ).
+'$lgt_normalize_error_term_aux'(
+	type_error(evaluable, Expression),
+	type_error(evaluable, Functor/Arity)
+) :-
+	callable(Expression),
+	Expression \= _/_,
+	functor(Expression, Functor, Arity).
 '$lgt_normalize_error_term_aux'(
 	Error,
 	Error
@@ -775,11 +775,22 @@ term_hash(_, _, _, _) :-
 	logtalk_make(clean).
 {?} :-
 	!,
-	logtalk_make(missing).
+	logtalk_make(check).
 {@} :-
 	!,
 	logtalk_make(circular).
-
+{#} :-
+	!,
+	logtalk_make(documentation).
+{+d} :-
+	!,
+	logtalk_make(debug).
+{+n} :-
+	!,
+	logtalk_make(normal).
+{+o} :-
+	!,
+	logtalk_make(optimal).
 
 {File, Files} :-
 	!,
