@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for YAP Prolog 6.3.4 and later versions
-%  Last updated on August 7, 2016
+%  Last updated on December 11, 2017
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -26,6 +26,7 @@
 
 :- use_module(library(system)).
 :- use_module(library(terms), [term_hash/4]).
+:- use_module(library(lists), [member/2]).
 
 :- set_prolog_flag(update_semantics, logical).
 :- set_prolog_flag(unknown, error).
@@ -282,12 +283,17 @@
 '$lgt_prolog_feature'(tabling, Tabling) :-
 	(	current_prolog_flag(system_options, tabling) ->
 		Tabling = supported
+	;	current_prolog_flag(system_options, Options),
+		member(tabling, Options) ->
+		Tabling = supported
 	;	Tabling = unsupported
 	).
 '$lgt_prolog_feature'(threads, Threads) :-
 	(	current_prolog_flag(system_options, threads) ->
-		Threads = supported,
-		thread_local('$lgt_engine_term_queue_'/2)
+		Threads = supported
+	;	current_prolog_flag(system_options, Options),
+		member(threads, Options) ->
+		Threads = supported
 	;	Threads = unsupported
 	).
 '$lgt_prolog_feature'(modules, supported).
@@ -329,7 +335,11 @@
 		ScratchDirectory = './.lgt_tmp/'
 	;	ScratchDirectory = './lgt_tmp/'
 	).
-'$lgt_default_flag'(report, on).
+'$lgt_default_flag'(report, Report) :-
+	(	current_prolog_flag(verbose, normal) ->
+		Report = on
+	;	Report = warnings
+	).
 '$lgt_default_flag'(clean, on).
 '$lgt_default_flag'(code_prefix, '$').
 '$lgt_default_flag'(optimize, off).
@@ -571,7 +581,7 @@
 % '$lgt_read_term'(@stream, -term, +list, -position, -list)
 
 '$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
-	read_term(Stream, Term, [term_position(PositionBegin), variable_names(Variables)| Options]),
+	read_term(Stream, Term, [syntax_errors(error), term_position(PositionBegin), variable_names(Variables)| Options]),
 	stream_position_data(line_count, PositionBegin, LineBegin),
 	stream_position(Stream, PositionEnd),
 	stream_position_data(line_count, PositionEnd, LineEnd).
@@ -610,20 +620,6 @@
 	logtalk_load_context(entity_type, module),					% only when we're compiling a module as an object!
 	'$lgt_compile_predicate_indicators'(PIs, _, CPIs).
 
-'$lgt_yap_directive_expansion'(table(F/A), {table(TF/TA)}) :-
-	logtalk_load_context(entity_type, _),
-	'$lgt_compile_predicate_indicators'(F/A, _, TF/TA).
-
-'$lgt_yap_directive_expansion'(table([F/A| PIs]), {table(TPIs)}) :-
-	logtalk_load_context(entity_type, _),
-	'$lgt_compile_predicate_indicators'([F/A| PIs], _, TPIs).
-
-'$lgt_yap_directive_expansion'(table(Head), {table(THead)}) :-
-	logtalk_load_context(entity_type, _),
-	'$lgt_compile_predicate_heads'(Head, _, THead, _),
-	functor(THead, _, Arity),
-	arg(Arity, THead, first).
-
 '$lgt_yap_directive_expansion'(encoding(Encoding1), encoding(Encoding2)) :-
 	nonvar(Encoding1),
 	'$lgt_yap_encoding_to_logtalk_encoding'(Encoding1, Encoding2).
@@ -649,6 +645,34 @@
 	logtalk_load_context(entity_type, _),
 	'$lgt_yap_list_of_exports'(File, Module, Imports).
 
+'$lgt_yap_directive_expansion'(table(Predicates), {table(TPredicates)}) :-
+	logtalk_load_context(entity_type, _),
+	'$lgt_yap_table_directive_expansion'(Predicates, TPredicates).
+
+
+'$lgt_yap_table_directive_expansion'([Predicate| Predicates], [TPredicate| TPredicates]) :-
+	!,
+	'$lgt_yap_table_directive_predicate'(Predicate, TPredicate),
+	'$lgt_yap_table_directive_expansion'(Predicates, TPredicates).
+
+'$lgt_yap_table_directive_expansion'((Predicate, Predicates), (TPredicate, TPredicates)) :-
+	!,
+	'$lgt_yap_table_directive_predicate'(Predicate, TPredicate),
+	'$lgt_yap_table_directive_expansion'(Predicates, TPredicates).
+
+'$lgt_yap_table_directive_expansion'(Predicate, TPredicate) :-
+	'$lgt_yap_table_directive_predicate'(Predicate, TPredicate).
+
+
+'$lgt_yap_table_directive_predicate'(F/A, TF/TA) :-
+	!,
+	'$lgt_compile_predicate_indicators'(F/A, _, TF/TA).
+
+'$lgt_yap_table_directive_predicate'(Head, THead) :-
+	'$lgt_compile_predicate_heads'(Head, _, THead, _),
+	functor(THead, _, Arity),
+	arg(Arity, THead, first).
+
 
 '$lgt_yap_list_of_exports'(File, Module, Exports) :-
 	(	absolute_file_name(File, Path, [file_type(prolog), access(read), file_errors(fail)]),
@@ -807,15 +831,19 @@ user:goal_expansion(phrase(Rule, Input), ExpandedGoal) :-
 	!,
 	'$lgt_execution_context'(ExCtx, user, user, user, user, [], []),
 	'$lgt_user_module_qualification'('$lgt_phrase'(Rule, Input, ExCtx), ExpandedGoal).
-% optimize messages sent from within modules
+% optimize messages sent from modules (including "user")
 user:goal_expansion('::'(Object, Message), ExpandedGoal) :-
-	prolog_load_context(module, Module),
-	% not top-level query
-	Module \== user,
-	'$lgt_compiler_flag'(events, Events),
-	prolog_load_context(term_position, Position),
-	stream_position_data(line_count, Position, Line),
-	'$lgt_comp_ctx'(Ctx, _, user, user, user, Obj, _, [], [], ExCtx, compile(aux), [], Line-Line),
+	(	prolog_load_context(module, user) ->
+		Events = allow
+	;	'$lgt_compiler_flag'(events, Events)
+	),
+	(	prolog_load_context(term_position, Position),
+		stream_position_data(line_count, Position, Line) ->
+		true
+	;	% top-level goal
+		Line = -1
+	),
+	'$lgt_comp_ctx'(Ctx, _, _, user, user, user, Obj, _, [], [], ExCtx, compile(aux), [], Line-Line),
 	'$lgt_execution_context'(ExCtx, user, user, user, Obj, [], []),
 	catch('$lgt_compile_message_to_object'(Message, Object, Goal, Events, Ctx), _, fail),
 	'$lgt_user_module_qualification'(Goal, ExpandedGoal).
@@ -949,11 +977,22 @@ term_expansion(
 	logtalk_make(clean).
 {?} :-
 	!,
-	logtalk_make(missing).
+	logtalk_make(check).
 {@} :-
 	!,
 	logtalk_make(circular).
-
+{#} :-
+	!,
+	logtalk_make(documentation).
+{+d} :-
+	!,
+	logtalk_make(debug).
+{+n} :-
+	!,
+	logtalk_make(normal).
+{+o} :-
+	!,
+	logtalk_make(optimal).
 
 {File, Files} :-
 	!,
