@@ -4,7 +4,7 @@ module Rouge
   module Lexers
     class Logtalk < RegexLexer
       title "Logtalk"
-      desc "The Logtalk programming language (http://logtalk.org/)"
+      desc "The Logtalk programming language (https://logtalk.org/)"
       tag 'logtalk'
       aliases 'logtalk'
       filenames '*.lgt', '*.logtalk'
@@ -33,7 +33,7 @@ module Rouge
         # Message forwarding handler
         rule /forward(?=[(])/, Keyword
         # Execution-context methods
-        rule /(parameter|this|self|sender)(?=[(])/, Keyword
+        rule /(context|parameter|this|self|sender)(?=[(])/, Keyword
         # Reflection
         rule /(current_predicate|predicate_property)(?=[(])/, Keyword
         # DCGs and term expansion
@@ -61,7 +61,8 @@ module Rouge
         rule /(abolish|asserta|assertz)(?=[(])/, Keyword
         # Control constructs
         rule /(call|catch|throw)(?=[(])/, Keyword
-        rule /(fail|false|true)\b/, Keyword
+        rule /(fail|false|true|instantiation_error)\b/, Keyword
+        rule /(type_error|domain_error|existence_error|permission_error|representation_error|evaluation_error|resource_error)(?=[(])/, Keyword
         # All solutions
         rule /(bagof|setof|findall|forall)(?=[(])/, Keyword
         # Multi-threading meta-predicates
