@@ -1,12 +1,12 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
 #############################################################################
 ## 
 ##   Integration script for CxProlog
-##   Last updated on October 11, 2013
+##   Last updated on February 6, 2018
 ## 
-##   This file is part of Logtalk <http://logtalk.org/>  
-##   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+##   This file is part of Logtalk <https://logtalk.org/>  
+##   Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
@@ -79,8 +79,8 @@ if [ -d "$LOGTALKUSER" ]; then
 		echo "Creating an up-to-date Logtalk user directory..."
 		logtalk_user_setup
 	else
-		system_version=`cat "$LOGTALKHOME/VERSION.txt"`
-		user_version=`cat "$LOGTALKUSER/VERSION.txt"`
+		system_version=$(cat "$LOGTALKHOME/VERSION.txt")
+		user_version=$(cat "$LOGTALKUSER/VERSION.txt")
 		if [ "$user_version" \< "$system_version" ]; then
 			echo "Logtalk user directory at $LOGTALKUSER is outdated: "
 			echo "    $user_version < $system_version"
@@ -93,8 +93,7 @@ else
 	echo "by running the \"logtalk_user_setup\" shell script:"
 	logtalk_user_setup
 fi
-echo
 
-export LOGTALK_STARTUP_DIRECTORY=`pwd`
+export LOGTALK_STARTUP_DIRECTORY=$(pwd)
 
 exec cxprolog --script "$LOGTALKHOME/integration/logtalk_cx.pl" "$@"
