@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Integration file for YAP
-%  Last updated on October 11, 2013
+%  Last updated on May 5, 2017
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -21,10 +21,11 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
-% load Logtalk core files
 :- initialization((
+	% load Logtalk core files
 	reconsult('$LOGTALKHOME/adapters/yap.pl'),
 	reconsult('$LOGTALKHOME/paths/paths.pl'),
 	reconsult('$LOGTALKHOME/integration/logtalk_comp_yap.pl'),
+	% load integration hooks with YAP native developer tools
 	reconsult('$LOGTALKHOME/adapters/yaphooks.pl')
 )).
