@@ -1,12 +1,12 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
 #############################################################################
 ## 
 ##   Distribution clean script for packaging
-##   Last updated on January 15, 2015
+##   Last updated on June 23, 2017
 ## 
-##   This file is part of Logtalk <http://logtalk.org/>  
-##   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+##   This file is part of Logtalk <https://logtalk.org/>  
+##   Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
@@ -45,6 +45,7 @@ chmod a-x scripts/*.js
 chmod a+x scripts/debian/postinst
 chmod a+x scripts/debian/prerm
 chmod a+x scripts/debian/postrm
+chmod a+x scripts/docker/swi-prolog/*.sh
 chmod a+x scripts/linux/*.sh
 chmod a+x scripts/macosx/postflight
 chmod a+x scripts/macosx/command_files/*.command
