@@ -1,12 +1,12 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
 #############################################################################
 ## 
 ##   Logtalk installation script
-##   Last updated on September 29, 2016
+##   Last updated on February 17, 2017
 ## 
-##   This file is part of Logtalk <http://logtalk.org/>  
-##   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+##   This file is part of Logtalk <https://logtalk.org/>  
+##   Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
@@ -27,17 +27,20 @@ if [ -f "/etc/debian_version" ]; then
 	default_prefix=/usr
 else
 	case $( uname -s ) in
-		Darwin	) default_prefix=/opt/local;;
-		*		) default_prefix=/usr/local;;
+		Darwin ) default_prefix=/opt/local;;
+		*      ) default_prefix=/usr/local;;
 	esac
 fi
 
-version=`cat ../VERSION.txt`
+# allow using this script from any directory
+cd "$(dirname "$0")" || exit 1
+
+version=$(cat ../VERSION.txt)
 default_directory=logtalk-$version
 
 print_version() {
-	echo "Current `basename $0` version:"
-	echo "  0.2"
+	echo "Current $(basename "$0") version:"
+	echo "  0.4"
 	exit 0
 }
 
@@ -48,9 +51,9 @@ usage_help()
 	echo "It may require a user with administrative privileges or the use of sudo."
 	echo
 	echo "Usage:"
-	echo "  `basename $0` [-p prefix] [-d directory]"
-	echo "  `basename $0` -v"
-	echo "  `basename $0` -h"
+	echo "  $(basename "$0") [-p prefix] [-d directory]"
+	echo "  $(basename "$0") -v"
+	echo "  $(basename "$0") -h"
 	echo
 	echo "Optional arguments:"
 	echo "  -p prefix directory for the installation (default is $default_prefix)"
@@ -77,15 +80,15 @@ if [ "$prefix_argument" != "" ] && [ ! -d "$prefix_argument" ] ; then
 	usage_help
 	exit 1
 elif [ "$prefix_argument" != "" ] ; then
-	prefix=$prefix_argument
+	prefix="$prefix_argument"
 else
-	prefix=$default_prefix
+	prefix="$default_prefix"
 fi
 
 if [ "$directory_argument" != "" ] ; then
-	directory=$directory_argument
+	directory="$directory_argument"
 else
-	directory=$default_directory
+	directory="$default_directory"
 fi
 
 if [ ! -w "$prefix" ] ; then
@@ -98,25 +101,24 @@ echo
 echo "Installing Logtalk $version on $prefix/share ..."
 echo
 
-mkdir -p $prefix/share
+mkdir -p "$prefix/share"
 
-rm -rf $prefix/share/$directory
-rm -f $prefix/share/logtalk
+rm -rf "$prefix/share/$directory"
+rm -f "$prefix/share/logtalk"
 
-mkdir $prefix/share/$directory
+mkdir "$prefix/share/$directory"
 
-cd ..
-cp -R * $prefix/share/$directory
+cp -R ../* "$prefix/share/$directory"
 
-cd $prefix/share/$directory
+cd "$prefix/share/$directory" || exit 1
 chmod a+x scripts/cleandist.sh
 scripts/cleandist.sh
 
 cd ..
-ln -sf $directory logtalk
+ln -sf "$directory" logtalk
 
-mkdir -p $prefix/bin
-cd $prefix/bin
+mkdir -p "$prefix/bin"
+cd "$prefix/bin" || exit 1
 
 ln -sf ../share/logtalk/scripts/logtalk_tester.sh logtalk_tester
 ln -sf ../share/logtalk/scripts/logtalk_doclet.sh logtalk_doclet
@@ -151,10 +153,10 @@ ln -sf ../share/logtalk/integration/xsbmtlgt.sh xsbmtlgt
 ln -sf ../share/logtalk/integration/yaplgt.sh yaplgt
 
 mkdir -p ../share/man/man1
-cd ../share/man/man1
+cd ../share/man/man1 || exit 1
 gzip --best ../../logtalk/man/man1/*.1
 for file in ../../logtalk/man/man1/*.1.gz ; do
-	ln -sf $file `basename $file`
+	ln -sf "$file" "$(basename "$file")"
 done
 
 echo "The following integration scripts are installed for running Logtalk"
@@ -163,15 +165,15 @@ echo
 echo "* B-Prolog (version 7.8 or later):         bplgt"
 echo "* CxProlog (version 0.98.1 or later):      cxlgt"
 echo "* ECLiPSe (version 6.1#143 or later):      eclipselgt"
-echo "* GNU Prolog (version 1.4.2 or later):     gplgt"
-echo "* JIProlog (version 4.1.2.8 or later):     jiplgt      (first run may require sudo)"
+echo "* GNU Prolog (version 1.4.5 or later):     gplgt"
+echo "* JIProlog (version 4.1.6.1 or later):     jiplgt      (first run may require sudo)"
 echo "* Lean Prolog (version 4.5.4 or later):    lplgt       (experimental)"
 echo "* Qu-Prolog (version 9.7 or later):        qplgt"
 echo "* Quintus Prolog (version 3.3 or later):   quintuslgt  (experimental)"
 echo "* SICStus Prolog (version 4.1.0 or later): sicstuslgt"
 echo "* SWI-Prolog (version 6.6.0 or later):     swilgt"
-echo "* XSB (version 3.5.0 or later):            xsblgt      (first run may require sudo)"
-echo "* XSB MT (version 3.5.0 or later):         xsbmtlgt    (first run may require sudo)"
+echo "* XSB (version 3.8.0 or later):            xsblgt      (first run may require sudo)"
+echo "* XSB MT (version 3.8.0 or later):         xsbmtlgt    (first run may require sudo)"
 echo "* YAP (version 6.3.4 or later):            yaplgt"
 echo
 echo "Links to the Prolog integration scripts can be found on \"$prefix/bin\"."
@@ -187,11 +189,11 @@ echo "scripts, consult the \"$prefix/share/logtalk/adapters/NOTES.md\" file"
 echo "for compatibility notes or consult the integration script man page."
 echo
 
-if [ "`command -v update-mime-database`" != "" ]; then
-	mkdir -p $prefix/share/mime/packages
-	rm -f $prefix/share/mime/packages/logtalk.xml
-	cp $prefix/share/$directory/scripts/freedesktop/logtalk.xml $prefix/share/mime/packages/logtalk.xml
-	update-mime-database $prefix/share/mime
+if [ "$(command -v update-mime-database)" != "" ]; then
+	mkdir -p "$prefix/share/mime/packages"
+	rm -f "$prefix/share/mime/packages/logtalk.xml"
+	cp "$prefix/share/$directory/scripts/freedesktop/logtalk.xml" "$prefix/share/mime/packages/logtalk.xml"
+	update-mime-database "$prefix/share/mime"
 	echo "Added the Logtalk mime-type to the Shared MIME-info Database."
 	echo
 fi
