@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
 //
 //   Logtalk user folder setup script
-//   Last updated on July 7, 2016
+//   Last updated on May 20, 2017
 //
-//   This file is part of Logtalk <http://logtalk.org/>  
-//   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+//   This file is part of Logtalk <https://logtalk.org/>  
+//   Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 //   
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -99,9 +99,8 @@ if (FSObject.FolderExists(logtalk_user)) {
 		FSObject.CopyFile(logtalk_user + "-backup-" + date + "\\settings.logtalk", logtalk_user + "\\settings.logtalk");
 		WScript.Echo("Copied your old \"settings.logtalk\" file to the new \"\%LOGTALKUSER\%\" directory.");
 	}
-	WScript.Echo("The file \"settings-sample.lgt\" file contains a pristine copy of the ");
-	WScript.Echo("\"settings-sample.lgt\" file distributed with the currently installed Logtalk");
-	WScript.Echo("version. Review this file for possible settings files update information.");
+	WScript.Echo("If you are upgrading from a previous Logtalk version, check the file");
+	WScript.Echo("\"\%LOGTALKUSER\%\\settings-sample.lgt\" for updated settings suggestions.");
 	WScript.Echo("");
 }
 
@@ -210,8 +209,8 @@ link.Save();
 WScript.Echo("Finished copying Logtalk files and directories.");
 WScript.Echo("");
 WScript.Echo("You may want to customize the default Logtalk compiler flags by renaming");
-WScript.Echo("and editing the \"settings-sample.lgt\" file found in the directory");
-WScript.Echo("\"\%LOGTALKUSER\%\". For more information on customizing Logtalk and your");
+WScript.Echo("and editing the \"settings-sample.lgt\" source file found in the directory");
+WScript.Echo("\"\%LOGTALKUSER\%\". For more information on how to customize Logtalk and the");
 WScript.Echo("working environment, consult the \"\%LOGTALKUSER\%\\CUSTOMIZE.md\" file.");
 WScript.Echo("");
 
@@ -219,10 +218,10 @@ WScript.Quit(0);
 
 function usage_help() {
 	WScript.Echo("");
-	WScript.Echo("This script copies the Logtalk per-user files and directories to the");
-	WScript.Echo("user home directory. The location can be set by the environment");
-	WScript.Echo("variable \"\%LOGTALKUSER\%\" (defaults to \"MyDocuments\\logtalk\" when the");
-	WScript.Echo("variable is not defined)");
+	WScript.Echo("This script copies all the Logtalk per-user files and directories to the");
+	WScript.Echo("user home directory. The location can be set by the environment variable");
+	WScript.Echo("\"\%LOGTALKUSER\%\" (defaults to \"MyDocuments\\logtalk\" when the variable is");
+	WScript.Echo("not defined)");
 	WScript.Echo("");
 	WScript.Echo("Usage:");
 	WScript.Echo("  " + WScript.ScriptName + " help");
