@@ -3,10 +3,10 @@
 #############################################################################
 ## 
 ##   Logtalk user folder setup script
-##   Last updated on July 7, 2016
+##   Last updated on May 14, 2017
 ## 
-##   This file is part of Logtalk <http://logtalk.org/>  
-##   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+##   This file is part of Logtalk <https://logtalk.org/>  
+##   Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
@@ -23,10 +23,9 @@
 #############################################################################
 
 echo
-echo "This script copies the Logtalk per-user files and directories to the"
-echo "user home directory. The location can be set by the environment"
-echo "variable \$LOGTALKUSER (defaults to \"~/logtalk\" when the variable is not"
-echo "defined)"
+echo "This script copies all the Logtalk per-user files and directories to the"
+echo "user home directory. The location can be set by the environment variable"
+echo "\$LOGTALKUSER (defaults to \"~/logtalk\" when the variable is not defined)"
 echo
 
 if ! [ "$LOGTALKHOME" ]; then
@@ -67,7 +66,7 @@ fi
 
 if ! [ "$LOGTALKUSER" ]
 then
-	LOGTALKUSER=$HOME/logtalk
+	LOGTALKUSER="$HOME/logtalk"
 	echo "After the script completion, you must set the environment variable"
 	echo "LOGTALKUSER pointing to \"$LOGTALKUSER\"."
 	echo
@@ -75,8 +74,8 @@ fi
 
 if [ -d "$LOGTALKUSER" ]
 then
-	date=`eval date \"+%Y-%m-%d-%H%M%S\"`
-	mv $LOGTALKUSER "$LOGTALKUSER-backup-$date"
+	date=$(eval date \"+%Y-%m-%d-%H%M%S\")
+	mv "$LOGTALKUSER" "$LOGTALKUSER-backup-$date"
 	echo "Created a backup of the existing \"\$LOGTALKUSER\" directory:"
 	echo
 	echo "  $LOGTALKUSER-backup-$date"
@@ -85,7 +84,7 @@ then
 	echo
 	echo "  $LOGTALKUSER"
 	echo
-	mkdir $LOGTALKUSER
+	mkdir "$LOGTALKUSER"
 	if [ -f "$LOGTALKUSER-backup-$date"/settings.lgt ]
 	then
 		cp "$LOGTALKUSER-backup-$date"/settings.lgt "$LOGTALKUSER"/
@@ -96,16 +95,15 @@ then
 		cp "$LOGTALKUSER-backup-$date"/settings.logtalk "$LOGTALKUSER"/
 		echo "Copied your old \"settings.logtalk\" file to the new \"\$LOGTALKUSER\" directory."
 	fi
-	echo "The file \"settings-sample.lgt\" file contains an up-to-date copy of the"
-	echo "\"settings-sample.lgt\" file distributed with the currently installed Logtalk"
-	echo "version. Review this file for possible settings files update information."
+	echo "If you are upgrading from a previous Logtalk version, check the file"
+	echo "\"\$LOGTALKUSER/settings-sample.lgt\" for updated settings suggestions."
 	echo
 else
 	echo "Creating a new \"\$LOGTALKUSER\" directory:"
 	echo
 	echo "  $LOGTALKUSER"
 	echo
-	mkdir $LOGTALKUSER
+	mkdir "$LOGTALKUSER"
 fi
 
 echo "Copying Logtalk files and directories..."
@@ -158,7 +156,7 @@ ln -sf "$LOGTALKHOME"/tools/lgtdoc/xml/logtalk_index.xsd "$LOGTALKUSER"/tools/lg
 echo "Finished copying Logtalk files and directories."
 echo
 echo "You may want to customize the default Logtalk compiler flags by renaming"
-echo "and editing the \"settings-sample.lgt\" file found in the directory"
-echo "\"\$LOGTALKUSER\". For more information on customizing Logtalk and your"
+echo "and editing the \"settings-sample.lgt\" source file found in the directory"
+echo "\"\$LOGTALKUSER\". For more information on how to customize Logtalk and the"
 echo "working environment, consult the \"\$LOGTALKUSER/CUSTOMIZE.md\" file."
 echo
