@@ -1,8 +1,8 @@
 name(logtalk).
 title('Logtalk - Object-Oriented Logic Programming Language').
-version('3.08.0').
+version('3.15.0').
 author('Paulo Moura', 'pmoura@logtalk.org').
 packager('Paulo Moura', 'pmoura@logtalk.org').
 maintainer('Paulo Moura', 'pmoura@logtalk.org').
-home('http://logtalk.org/').
-download('http://logtalk.org/files/swi-prolog/packs/logtalk-3.08.0.tgz').
+home('https://logtalk.org/').
+download('https://logtalk.org/files/swi-prolog/packs/logtalk-3.15.0.tgz').
