@@ -3,8 +3,8 @@
 %  Support for load-on-demand using SWI Prolog 6.6.0 and later versions
 %  Last updated on February 14, 2016
 %
-%  This file is part of Logtalk <http://logtalk.org/>  
-%  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+%  This file is part of Logtalk <https://logtalk.org/>  
+%  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -24,7 +24,7 @@
 :- module(logtalk, []).
 
 :-	prolog_load_context(directory, Directory),
-	atom_concat(Directory, '/../logtalk-3.08.0/', Location),
+	atom_concat(Directory, '/../logtalk-3.15.0/', Location),
 	setenv('LOGTALKHOME', Location),
 	setenv('LOGTALKUSER', Location),
-	user:load_files('../logtalk-3.08.0/integration/logtalk_swi.pl').
+	user:load_files('../logtalk-3.15.0/integration/logtalk_swi.pl').
